@@ -3,24 +3,24 @@
 from .auth import Auth
 from .config import BY_PASS_LOGIN
 from .trainer import Trainer
-from .yolov5_wrapper import verifyInstall
+from .yolov5_wrapper import verify_install
 
 auth = Auth()
 
 
-def setupYOLO() -> None:
+def setup_yolo() -> None:
     """Checks if yolov5 exists and if not clones it"""
-    verifyInstall()
+    verify_install()
 
 
-def trainModel() -> None:
+def train_model() -> None:
     """Starts training from next in queue"""
     trainer = Trainer(None, auth)  # No model so next in train queue is fetched
     if trainer.model is not None:
         trainer.start()
 
 
-def connectToHUB(password=False) -> bool:
+def connect_to_hub(password=False) -> bool:
     """Authenticates user with Ultralytics HUB"""
 
     if password:
@@ -32,16 +32,15 @@ def connectToHUB(password=False) -> bool:
 
 
 def main():
-    setupYOLO()
+    setup_yolo()
     if BY_PASS_LOGIN:
-        auth.sign_in_with_email_and_password("kalen.michael@ultralytics.com",
-                                             "7654321")
+        auth.sign_in_with_email_and_password("kalen.michael@ultralytics.com", "7654321")
         if auth.idToken:
-            trainModel()
+            train_model()
         else:
             print("Incorrect Login Details.")
-    elif connectToHUB():
-        trainModel()
+    elif connect_to_hub():
+        train_model()
 
 
 main()
